@@ -23,21 +23,23 @@ def validate_categorical(setting, name, allowed):
 
 @dataclass
 class EnvVar():
-    env: str
+    env: Optional[str] = None
     service_name: Optional[str] = None
     google_project_id: Optional[str] = None
     platform: Optional[str] = None
     local_deployment: bool = False
 
     def __post_init__(self):        
-        validate_categorical(self.env, "Environment", ["dev", "test", "prod"])
+        if self.env:
+            validate_categorical(self.env, "Environment", ["dev", "test", "prod"])
+        else:
+            logging.warning("ENV environmental variable is not set")
         validate_categorical(self.platform, "Platform", ["cdf", "gc", None])
-        if self.env != 'dev':
+        if (self.env and self.env != 'dev'):
             validate_categorical(self.service_name, "Service  name", 
                 ["training", "prediction"])
 
 
-# Read environmental variables
 def _read_env_vars():
     """
     Read environmental variables and initialize EnvVar object with those that
@@ -76,10 +78,10 @@ def update_cdf_keys(new_keys):
 
 
 def generate_default_project_settings(
-    yaml_file='mlops_settings.yaml', 
+    yaml_file=Path('mlops_settings.yaml'), 
     n_models=2
 ):
-    if os.path.isfile(yaml_file):
+    if yaml_file.exists():
         raise Exception(f"Settings file {yaml_file} exists already.")
     
     default_config = [ 
@@ -90,6 +92,7 @@ req_file: model_code/requirements.model
 test_file: model_code/test_model.py
 artifact_folder: artifact_folder
 platform: cdf
+dataset: mlops
 info:
     prediction: 
         description: Description prediction service for my_model
@@ -123,18 +126,19 @@ class ServiceSettings():
     model_name: str # Remember to modify generate_default_project_settings()
     model_file: FilePath # if fields are modified
     req_file: FilePath
-    test_file: FilePath
-    artifact_folder: Path
+    test_file: Optional[FilePath]
+    artifact_folder: Optional[Path]
     info: dict
     platform: str = 'cdf'
+    dataset: Optional[str] = 'mlops'
     model_id: Optional[str] = None
 
 
     def __post_init_post_parse__(self):
         # Validation
-        if not re.match("^[A-Za-z0-9_-]*$", self.model_name):
-            raise Exception("Model name can only contain letters, numbers"
-                            "underscores and dashes")
+        if not re.match("^[A-Za-z0-9_]*$", self.model_name):
+            m = "Model name can only contain letters, numbers and underscores"
+            raise Exception(m)
 
         validate_model_reqs(self.req_file)
 
@@ -156,7 +160,7 @@ class ServiceSettings():
 
         self.files = {
             "model code": helpers.get_top_folder(self.model_file), 
-            "handler": (f"akerbp.mlops.cdf","handler.py"),
+            "handler": ("akerbp.mlops.cdf", "handler.py"),
             "artifact folder": self.artifact_folder
         }
         if self.platform == "gc":
